/*  -*- c++ -*-
    xfaceconfigurator.cpp

    KMail, the KDE mail client.
    Copyright (c) 2002 the KMail authors.
    See file AUTHORS for details

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License,
    version 2.0, as published by the Free Software Foundation.
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, US
*/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "xfaceconfigurator.h"

#include <klocale.h>
#include <kdialog.h>
#include <kglobalsettings.h>
#include "kxface.h"

#include <qlabel.h>
#include <qlayout.h>
#include <qcheckbox.h>
#include <qtextedit.h>
#include <qwhatsthis.h>
#include <qbitmap.h>

#include <assert.h>

using namespace KMail;

namespace KMail {

  XFaceConfigurator::XFaceConfigurator( QWidget * parent, const char * name )
    : QWidget( parent, name )
  {
    // tmp. vars:
    QLabel * label;
    QVBoxLayout * vlay;
    QHBoxLayout * hlay;

    vlay = new QVBoxLayout( this, 0, KDialog::spacingHint(), "main layout" );
    hlay = new QHBoxLayout( vlay );

    // "enable X-Face" checkbox:
    mEnableCheck = new QCheckBox( i18n("&Enable X-Face header"), this );
    QWhatsThis::add(mEnableCheck, 
        i18n("Check this box if you want KMail to add a X-Face header to mails "
             "written with this identity."));
    hlay->addWidget( mEnableCheck, Qt::AlignLeft | Qt::AlignVCenter );
    
    mXFaceLabel = new QLabel( this );
    QWhatsThis::add(mXFaceLabel, 
        i18n("This is a preview of the X-Face entered in the text box below."));
    mXFaceLabel->setFixedSize(48, 48);
    hlay->addWidget( mXFaceLabel );

    label = new QLabel(  "X-Face:", this );
    vlay->addWidget( label );
    
    mTextEdit = new QTextEdit( this );
    QWhatsThis::add(mTextEdit, 
        i18n("Use this field to enter an X-Face header."));
    mTextEdit->setFont( KGlobalSettings::fixedFont() );
    mTextEdit->setWordWrap( QTextEdit::NoWrap );
    mTextEdit->setTextFormat( Qt::PlainText );
    vlay->addWidget( mTextEdit );
    
    connect(mTextEdit, SIGNAL(textChanged()), this, SLOT(slotUpdateXFace()));
  }

  XFaceConfigurator::~XFaceConfigurator() {

  }

  bool XFaceConfigurator::isXFaceEnabled() const {
    return mEnableCheck->isChecked();
  }

  void XFaceConfigurator::setXFaceEnabled( bool enable ) {
    mEnableCheck->setChecked( enable );
  }

  QString XFaceConfigurator::xface() const {
    return mTextEdit->text();
  }

  void XFaceConfigurator::setXFace( const QString & text ) {
    mTextEdit->setText( text );
  }
  
  void XFaceConfigurator::slotUpdateXFace()
  {
    if (!mTextEdit->text().isEmpty())
      mXFaceLabel->setPixmap( KXFace::uncomp(mTextEdit->text()) );
    else
      mXFaceLabel->setPixmap( 0L );
  }

} // namespace KMail

#include "xfaceconfigurator.moc"
